==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/sch_gantt.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
		</td>

		<td width="100%" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_schedule_gantt'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<?php
			if (isset($schedule_items)) {
			?>
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				
				<tr>
					<td>&nbsp;</td>
				<?php
				for ($c = 0; $c < $schedule_items['cells']; $c++) {
				?>
					<td>
						<?php echo $c;?><br />
					</td>
				<?php }?>
				</tr>
				
				
				<?php
				foreach($schedule_items['items'] as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if (isset($group)) {
						    $url = "sch_item.php?group_id=" . $group['group_id'] . "&amp;schedule_id=" . $i['schedule_id'];
						}
						else {
						    $url = "sch_item.php?schedule_id=" . $i['schedule_id'];
						}
						?>
					
						<a href="<?php echo $url;?>"><?php echo $i['schedule_title'];?></a><br />
					</td>
					<?php
					//width = approx 20% title and 80% chart
					$cell_width = round(80 / $schedule_items['cells']);
					
					for ($c = 0; $c < $schedule_items['cells']; $c++) {
						if ($i['cell_start']<=$c && $i['cell_end']>=$c) {
						?>
						<td width="<?php echo $cell_width;?>" id="gantt_on">
							<br />
						</td>
						<?php
						}
						else {
						?>
						<td width="<?php echo $cell_width?>" id="gantt_off">
							<br />
						</td>
						<?php
						}
					}
					?>
				</tr>
				<?php 
				endforeach;
				?>
			</table>
			<?php }?>
			</div>
			
			<div class="box_edit">
			<table cellpadding="2" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="right">
						<?php
						if (isset($group)) {
						    $url = "sch_edit.php?group_id=" . $group['group_id'] . "&amp;schedule_type_id=";
						}
						else {
						    $url = "sch_edit.php?schedule_type_id=";
						}
						?>
					
						<a href="<?php echo $url . $schedule_config['type']['event'];?>" class="link_stnd"><?php echo $lang['href_event_add'];?></a>&nbsp;
						<a href="<?php echo $url . $schedule_config['type']['task'];?>" class="link_stnd"><?php echo $lang['href_task_add'];?></a><br />
					</td>
				</tr>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>

==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/template/barnraiser_01/sch_gantt.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?php
			include $templatePath . "g_menu.inc.tpl.php";
			?>
		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" border="0" /><br />
		</td>

		<td width="100%" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_schedule_gantt'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			
			<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				if (isset($schedule_items)) {
				?>
				<tr>
					<td>&nbsp;</td>
				<?php
				for ($c = 0; $c < $schedule_items['cells']; $c++) {
				?>
					<td>
						<?php echo $c;?><br />
					</td>
				<?php }?>
				</tr>
				
				
				<?php
				foreach($schedule_items['items'] as $key => $i):
				?>
				<tr>
					<td>
						<?php
						if (isset($group)) {
						    $url = "sch_item.php?group_id=" . $group['group_id'] . "&amp;schedule_id=" . $i['schedule_id'];
						}
						else {
						    $url = "sch_item.php?schedule_id=" . $i['schedule_id'];
						}
						?>
					
						<a href="<?php echo $url;?>"><?php echo $i['schedule_title'];?></a><br />
					</td>
					<?php
					//width = approx 20% title and 80% chart
					$cell_width = round(80 / $schedule_items['cells']);
					
					for ($c = 0; $c < $schedule_items['cells']; $c++) {
						if ($i['cell_start']<=$c && $i['cell_end']>=$c) {
						?>
						<td width="<?php echo $cell_width;?>" id="gantt_on">
							<br />
						</td>
						<?php
						}
						else {
						?>
						<td width="<?php echo $cell_width?>" id="gantt_off">
							<br />
						</td>
						<?php
						}
					}
					?>
				</tr>
				<?php 
				endforeach;
				}
				?>
			</table>
			
			<table cellpadding="2" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="right">
						<div class="box_edit">
						<?php
						if (isset($group)) {
						    $url = "sch_edit.php?group_id=" . $group['group_id'] . "&amp;schedule_type_id=";
						}
						else {
						    $url = "sch_edit.php?schedule_type_id=";
						}
						?>
						
						<a href="sch_schedule.php?group_id=<?php echo $group['group_id'];?>" class="link_stnd"><?php echo $lang['href_schedule'];?></a>&nbsp;
						
						<a href="<?php echo $url . $schedule_config['type']['event'];?>" class="link_stnd"><?php echo $lang['href_event_add'];?></a>&nbsp;
						<a href="<?php echo $url . $schedule_config['type']['task'];?>" class="link_stnd"><?php echo $lang['href_task_add'];?></a><br />
						</div>
					</td>
				</tr>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
